@@ -1,5 +1,9 @@
 #!/bin/bash
 
+# get directory of script and cd to it
+DIR="$( cd "$( dirname "$0" )" && pwd )"
+cd $DIR
+
 echo "Insert your locale:";
 read locale;
 
